/**
 * Copyright (c) 2009-2012 EBM WebSourcing, 2012-2015 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see <http://www.gnu.org/licenses/>
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.launcher.api.service;

import java.io.Serializable;

/**
 * The location bean. 
 * <p>
 * Contains all the needed information to reach a service but
 * does NOT contains the endpoint itself!
 * </p>
 * 
 * @author Christophe Hamerling - EBM WebSourcing
 */
public class Location implements Serializable {

    /**
     * 
     */
    private static final long serialVersionUID = 6036195680156183050L;

    private String subdomainName;

    private String containerName;

    private String componentName;

    /**
     * 
     */
    public Location() {
    }

    /**
     * 
     * @param subdomainName
     * @param containerName
     * @param componentName
     */
    public Location(String subdomainName, String containerName, String componentName) {
        this.subdomainName = subdomainName;
        this.containerName = containerName;
        this.componentName = componentName;
    }

    public String getSubdomainName() {
        return this.subdomainName;
    }

    public String getContainerName() {
        return this.containerName;
    }

    public String getComponentName() {
        return this.componentName;
    }

    public void setSubdomainName(String subdomainName) {
        this.subdomainName = subdomainName;
    }

    public void setContainerName(String containerName) {
        this.containerName = containerName;
    }

    public void setComponentName(String componentName) {
        this.componentName = componentName;
    }

    @Override
    public String toString() {
        StringBuilder builder = new StringBuilder();
        builder.append("Location [componentName=");
        builder.append(this.componentName);
        builder.append(", containerName=");
        builder.append(this.containerName);
        builder.append(", subdomainName=");
        builder.append(this.subdomainName);
        builder.append("]");
        return builder.toString();
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result
                + ((this.componentName == null) ? 0 : this.componentName.hashCode());
        result = prime * result
                + ((this.containerName == null) ? 0 : this.containerName.hashCode());
        result = prime * result
                + ((this.subdomainName == null) ? 0 : this.subdomainName.hashCode());
        return result;
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj == null) {
            return false;
        }
        if (this.getClass() != obj.getClass()) {
            return false;
        }
        Location other = (Location) obj;
        if (this.componentName == null) {
            if (other.componentName != null) {
                return false;
            }
        } else if (!this.componentName.equals(other.componentName)) {
            return false;
        }
        if (this.containerName == null) {
            if (other.containerName != null) {
                return false;
            }
        } else if (!this.containerName.equals(other.containerName)) {
            return false;
        }
        if (this.subdomainName == null) {
            if (other.subdomainName != null) {
                return false;
            }
        } else if (!this.subdomainName.equals(other.subdomainName)) {
            return false;
        }
        return true;
    }

}
